@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Common Carla code
-# Copyright (C) 2011-2021 Filipe Coelho <falktx@falktx.com>
+# Copyright (C) 2011-2022 Filipe Coelho <falktx@falktx.com>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License as
@@ -71,7 +71,7 @@ if WINDOWS:
 # ------------------------------------------------------------------------------------------------------------
 # Set Version
 
-VERSION = "2.3.1"
+VERSION = "2.5.0"
 
 # ------------------------------------------------------------------------------------------------------------
 # Set TMP
@@ -183,6 +183,7 @@ CARLA_KEY_MAIN_USE_PRO_THEME    = "Main/UseProTheme"     # bool
 CARLA_KEY_MAIN_PRO_THEME_COLOR  = "Main/ProThemeColor"   # str
 CARLA_KEY_MAIN_REFRESH_INTERVAL = "Main/RefreshInterval" # int
 CARLA_KEY_MAIN_CONFIRM_EXIT     = "Main/ConfirmExit"     # bool
+CARLA_KEY_MAIN_CLASSIC_SKIN     = "Main/ClassicSkin"     # bool
 CARLA_KEY_MAIN_SHOW_LOGS        = "Main/ShowLogs"        # bool
 CARLA_KEY_MAIN_SYSTEM_ICONS     = "Main/SystemIcons"     # bool
 CARLA_KEY_MAIN_EXPERIMENTAL     = "Main/Experimental"    # bool
@@ -232,6 +233,7 @@ CARLA_KEY_PATHS_VST2   = "Paths/VST2"
 CARLA_KEY_PATHS_VST3   = "Paths/VST3"
 CARLA_KEY_PATHS_SF2    = "Paths/SF2"
 CARLA_KEY_PATHS_SFZ    = "Paths/SFZ"
+CARLA_KEY_PATHS_JSFX   = "Paths/JSFX"
 
 CARLA_KEY_WINE_EXECUTABLE      = "Wine/Executable"     # str
 CARLA_KEY_WINE_AUTO_PREFIX     = "Wine/AutoPrefix"     # bool
@@ -259,6 +261,7 @@ CARLA_DEFAULT_MAIN_USE_PRO_THEME    = True
 CARLA_DEFAULT_MAIN_PRO_THEME_COLOR  = "Black"
 CARLA_DEFAULT_MAIN_REFRESH_INTERVAL = 20
 CARLA_DEFAULT_MAIN_CONFIRM_EXIT     = True
+CARLA_DEFAULT_MAIN_CLASSIC_SKIN     = False
 CARLA_DEFAULT_MAIN_SHOW_LOGS        = bool(not WINDOWS)
 CARLA_DEFAULT_MAIN_SYSTEM_ICONS     = False
 CARLA_DEFAULT_MAIN_EXPERIMENTAL     = False
@@ -297,7 +300,7 @@ if WINDOWS:
     CARLA_DEFAULT_AUDIO_DRIVER = "DirectSound"
 elif MACOS:
     CARLA_DEFAULT_AUDIO_DRIVER = "CoreAudio"
-elif os.path.exists("/usr/bin/jackd") or os.path.exists("/usr/bin/jackdbus"):
+elif os.path.exists("/usr/bin/jackd") or os.path.exists("/usr/bin/jackdbus") or os.path.exists("/usr/bin/pw-jack"):
     CARLA_DEFAULT_AUDIO_DRIVER = "JACK"
 else:
     CARLA_DEFAULT_AUDIO_DRIVER = "PulseAudio"
@@ -350,11 +353,13 @@ DEFAULT_VST2_PATH   = ""
 DEFAULT_VST3_PATH   = ""
 DEFAULT_SF2_PATH    = ""
 DEFAULT_SFZ_PATH    = ""
+DEFAULT_JSFX_PATH   = ""
 
 if WINDOWS:
     splitter = ";"
 
     APPDATA = os.getenv("APPDATA")
+    LOCALAPPDATA = os.getenv("LOCALAPPDATA", APPDATA)
     PROGRAMFILES = os.getenv("PROGRAMFILES")
     PROGRAMFILESx86 = os.getenv("PROGRAMFILES(x86)")
     COMMONPROGRAMFILES = os.getenv("COMMONPROGRAMFILES")
@@ -385,10 +390,14 @@ if WINDOWS:
     DEFAULT_VST2_PATH    = PROGRAMFILES + "\\VstPlugins"
     DEFAULT_VST2_PATH   += ";" + PROGRAMFILES + "\\Steinberg\\VstPlugins"
 
+    DEFAULT_JSFX_PATH    = APPDATA + "\\REAPER\\Effects"
+    #DEFAULT_JSFX_PATH   += ";" + PROGRAMFILES + "\\REAPER\\InstallData\\Effects"
+
     if kIs64bit:
         DEFAULT_VST2_PATH  += ";" + COMMONPROGRAMFILES + "\\VST2"
 
     DEFAULT_VST3_PATH    = COMMONPROGRAMFILES + "\\VST3"
+    DEFAULT_VST3_PATH   += ";" + LOCALAPPDATA + "\\Programs\\Common\\VST3"
 
     DEFAULT_SF2_PATH     = APPDATA + "\\SF2"
     DEFAULT_SFZ_PATH     = APPDATA + "\\SFZ"
@@ -398,6 +407,7 @@ if WINDOWS:
         DEFAULT_DSSI_PATH   += ";" + PROGRAMFILESx86 + "\\DSSI"
         DEFAULT_VST2_PATH   += ";" + PROGRAMFILESx86 + "\\VstPlugins"
         DEFAULT_VST2_PATH   += ";" + PROGRAMFILESx86 + "\\Steinberg\\VstPlugins"
+        #DEFAULT_JSFX_PATH   += ";" + PROGRAMFILESx86 + "\\REAPER\\InstallData\\Effects"
 
     if COMMONPROGRAMFILESx86:
         DEFAULT_VST3_PATH   += COMMONPROGRAMFILESx86 + "\\VST3"
@@ -440,7 +450,12 @@ elif MACOS:
     DEFAULT_VST3_PATH    = HOME + "/Library/Audio/Plug-Ins/VST3"
     DEFAULT_VST3_PATH   += ":/Library/Audio/Plug-Ins/VST3"
 
+    DEFAULT_JSFX_PATH    = HOME + "/Library/Application Support/REAPER/Effects"
+    #DEFAULT_JSFX_PATH   += ":/Applications/REAPER.app/Contents/InstallFiles/Effects"
+
 else:
+    CONFIG_HOME = os.getenv("XDG_CONFIG_HOME", HOME + "/.config")
+
     splitter = ":"
 
     DEFAULT_LADSPA_PATH  = HOME + "/.ladspa"
@@ -468,7 +483,7 @@ else:
     DEFAULT_VST3_PATH   += ":/usr/local/lib/vst3"
 
     DEFAULT_SF2_PATH     = HOME + "/.sounds/sf2"
-    DEFAULT_SF2_PATH    += HOME + "/.sounds/sf3"
+    DEFAULT_SF2_PATH    += ":" + HOME + "/.sounds/sf3"
     DEFAULT_SF2_PATH    += ":/usr/share/sounds/sf2"
     DEFAULT_SF2_PATH    += ":/usr/share/sounds/sf3"
     DEFAULT_SF2_PATH    += ":/usr/share/soundfonts"
@@ -476,6 +491,9 @@ else:
     DEFAULT_SFZ_PATH     = HOME + "/.sounds/sfz"
     DEFAULT_SFZ_PATH    += ":/usr/share/sounds/sfz"
 
+    DEFAULT_JSFX_PATH    = CONFIG_HOME + "/REAPER/Effects"
+    #DEFAULT_JSFX_PATH   += ":" + "/opt/REAPER/InstallData/Effects"
+
 if not WINDOWS:
     winePrefix = os.getenv("WINEPREFIX")
 
@@ -523,6 +541,7 @@ if readEnvVars:
     CARLA_DEFAULT_VST3_PATH   = os.getenv("VST3_PATH",   DEFAULT_VST3_PATH).split(splitter)
     CARLA_DEFAULT_SF2_PATH    = os.getenv("SF2_PATH",    DEFAULT_SF2_PATH).split(splitter)
     CARLA_DEFAULT_SFZ_PATH    = os.getenv("SFZ_PATH",    DEFAULT_SFZ_PATH).split(splitter)
+    CARLA_DEFAULT_JSFX_PATH   = os.getenv("JSFX_PATH",   DEFAULT_JSFX_PATH).split(splitter)
 
 else:
     CARLA_DEFAULT_LADSPA_PATH = DEFAULT_LADSPA_PATH.split(splitter)
@@ -532,6 +551,7 @@ else:
     CARLA_DEFAULT_VST3_PATH   = DEFAULT_VST3_PATH.split(splitter)
     CARLA_DEFAULT_SF2_PATH    = DEFAULT_SF2_PATH.split(splitter)
     CARLA_DEFAULT_SFZ_PATH    = DEFAULT_SFZ_PATH.split(splitter)
+    CARLA_DEFAULT_JSFX_PATH   = DEFAULT_JSFX_PATH.split(splitter)
 
 # ------------------------------------------------------------------------------------------------------------
 # Default Plugin Folders (cleanup)
@@ -671,7 +691,8 @@ def handleInitialCommandLineArguments(file):
             print("")
             print("    --cnprefix\t Set a prefix for client names in multi-client mode.")
             if isinstance(gCarla.nogui, bool):
-                print("    --gdb     \t Run Carla inside gdb.")
+                if X_LIBDIR_X is not None:
+                    print("    --gdb     \t Run Carla inside gdb.")
                 print(" -n,--no-gui  \t Run Carla headless, don't show UI.")
                 print("")
             print(" -h,--help    \t Print this help text and exit.")
